from distutils.core import setup

setup(name='Vertudo - Project09090909',
      version='1.0',
      description='Tmp project',
      author='Vertudo-X',
      author_email='justgamee92@gmail.com',
      url='https://www.google.com/',
      packages=['module1', 'module2'],
     )
